@@ -1,4 +1,4 @@
-.First.lib <-
+.onLoad <-
 function(libname, pkgname) {
   library.dynam("RSvgDevice", pkgname, libname)
 }
